from __future__ import division

import Image, ImageDraw

def _genVals(img_w, img_h, valores):
    # si tenemos mas valores que pixeles, agrupamos
    if len(valores) > img_w:
        # calculamos cantpaq y sacamos el paso para el desplazamiento hztal
        paso_w = len(valores) / img_w
        cantpaq = int(paso_w)
        if paso_w != cantpaq:
            cantpaq += 1
        paso_w = cantpaq * img_w / len(valores)

        # creamos nuevos valores medios, ajustamos el multiplicador
        newvals = []
        for i in range(0,len(valores),cantpaq):
            vals = valores[i:i+cantpaq]
            valmed = sum(vals) / len(vals)  # len(vals) no siempre == cantpaq
            newvals.append(valmed)
        valores = newvals
    else:
        paso_w = img_w / len(valores)

    # metemos los valores dentro del alto
    # este +1 funciona con el -1 de abajo para que valores max y min
    # se dibujen y no se pierdan en el borde
    multip_h = (max(valores) + 1) / img_h

    xini = 0
    yini = img_h
    for val in valores:
        # este -1 funciona con el +1 de arriba para que valores
        # max y min se dibujen y no se pierdan en el borde
        posy = img_h - val/multip_h - 1
        yield (xini,yini,xini+paso_w, posy)
        xini += paso_w
        yini = posy
    return

def plotCurva(valores, imagesize, nomarch):
    """ Dibuja una curva a partir de valores iniciales.

    Adaptacion de un codigo de John Lenton.
    """
    img_w,img_h = imagesize
    im = Image.new("RGB", (img_w, img_h), (245,245,255))
    draw = ImageDraw.Draw(im)

    vals = _genVals(img_w, img_h, valores)
    for dx,dy,hx,hy in vals:
        draw.line((dx, dy, hx, hy), "green")

    im.save(nomarch, "PNG")
    return


if __name__ == "__main__":
    import sys
    if len(sys.argv) > 1:
        arch = sys.argv[1]
        print "Tomando valores de '%s', curva en 'test_curvas.png'" % arch
        vals = [int(x) for x in open(arch)]
        plotCurva(vals, (400, 50), "test_curvas.png")

    else:
        print "Generando valores al azar, curva en 'test_curvas.png'"
        import random
        vals = []
        ini = 0
        for i in range(random.randint(20,10000)):
            delta = random.randint(-3,3)
            vals.append(ini)
            ini += delta
            if ini < 0: ini = 0
        plotCurva(vals, (400, 50), "test_curvas.png")
